@@ -34,8 +34,6 @@
 #include <libart_lgpl/libart.h>
 #include <glade/glade-xml.h>
 
-#include "egg-screen-help.h"
-
 #define FISH_APPLET(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), \
 			fish_applet_get_type(),          \
 			FishApplet))
@@ -113,7 +111,7 @@ show_help (FishApplet *fish, const char *link_id)
 {
 	GError *error = NULL;
 
-	egg_help_display_desktop_on_screen (
+	gnome_help_display_desktop_on_screen (
 		NULL, "fish-applet-2", "fish-applet-2", link_id,
 		gtk_widget_get_screen (GTK_WIDGET (fish)),
 		&error);
