@@ -26,10 +26,9 @@
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
-#include <libgnome/gnome-help.h>
 #include <gtk/gtkmessagedialog.h>
 #include <gtk/gtkhbox.h>
-#include <libgnomeui/gnome-about.h>
+#include <libgnomeui/libgnomeui.h>
 
 #include <bonobo/bonobo-shlib-factory.h>
 
@@ -67,7 +66,10 @@ help_cb (PanelApplet *applet,
   GError *err;
 
   err = NULL;  
-  gnome_help_display ("notification-area-applet", NULL, &err);
+  gnome_help_display_desktop_on_screen (NULL, "user-guide",
+                                        "wgospanel.xml", "gospanel-567",
+					gtk_widget_get_screen (GTK_WIDGET (applet)),
+					&err);
 
   if (err != NULL)
     {
@@ -85,6 +87,8 @@ help_cb (PanelApplet *applet,
                         NULL);
       
       gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+      gtk_window_set_screen (GTK_WINDOW (dialog),
+                             gtk_widget_get_screen (GTK_WIDGET (applet)));
       
       gtk_widget_show (dialog);
 
