@@ -30,8 +30,6 @@
 
 #include "window-list.h"
 
-#include "egg-screen-help.h"
-
 typedef struct {
 	GtkWidget *applet;
 	GtkWidget *tasklist;
@@ -55,6 +53,7 @@ typedef struct {
 	GtkWidget *never_group_radio;
 	GtkWidget *auto_group_radio;
 	GtkWidget *always_group_radio;
+	GtkWidget *minimized_windows_label;
 	GtkWidget *move_minimized_radio;
 	GtkWidget *change_workspace_radio;
 
@@ -103,7 +102,7 @@ response_cb (GtkWidget    *widget,
 	if (id == GTK_RESPONSE_HELP) {
 		GError *error = NULL;
 
-		egg_help_display_desktop_on_screen (
+		gnome_help_display_desktop_on_screen (
 			NULL, "window-list", "window-list", "windowlist-prefs",
 			gtk_widget_get_screen (tasklist->applet),
 			&error);
@@ -248,6 +247,8 @@ destroy_tasklist(GtkWidget * widget, TasklistData *tasklist)
 	gconf_client_notify_remove (client, tasklist->listeners[2]);
 	gconf_client_notify_remove (client, tasklist->listeners[3]);
 	gconf_client_notify_remove (client, tasklist->listeners[4]);
+
+	g_object_unref (G_OBJECT (client));
 	
 	tasklist->listeners[0] = 0;
 	tasklist->listeners[1] = 0;
@@ -287,6 +288,13 @@ tasklist_properties_update_content_radio (TasklistData *tasklist)
 	
         if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+
+	gtk_widget_set_sensitive (tasklist->minimized_windows_label,
+				  tasklist->include_all_workspaces);
+	gtk_widget_set_sensitive (tasklist->move_minimized_radio,
+				  tasklist->include_all_workspaces);
+	gtk_widget_set_sensitive (tasklist->change_workspace_radio,
+				  tasklist->include_all_workspaces);
 }
 
 static void
@@ -513,7 +521,10 @@ setup_gconf (TasklistData *tasklist)
 				(GConfClientNotifyFunc)maximum_size_changed,
 				tasklist,
 				NULL, NULL);
-	g_free (key);}
+	g_free (key);
+
+	g_object_unref (G_OBJECT (client));
+}
 
 static void
 applet_size_request (GtkWidget      *widget,
@@ -725,6 +736,17 @@ window_list_applet_fill (PanelApplet *applet)
 					   NULL,
 					   tasklist_menu_verbs, 
 					   tasklist);
+
+	if (panel_applet_get_locked_down (PANEL_APPLET (tasklist->applet))) {
+		BonoboUIComponent *popup_component;
+
+		popup_component = panel_applet_get_popup_component (PANEL_APPLET (tasklist->applet));
+
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/TasklistPreferences",
+					      "hidden", "1",
+					      NULL);
+	}
 	
 	return TRUE;
 }
@@ -737,7 +759,7 @@ display_help_dialog (BonoboUIComponent *uic,
 {
 	GError *error = NULL;
 
-	egg_help_display_desktop_on_screen (
+	gnome_help_display_desktop_on_screen (
 			NULL, "window-list", "window-list", NULL,
 			gtk_widget_get_screen (tasklist->applet),
 			&error);
@@ -788,13 +810,15 @@ display_about_dialog (BonoboUIComponent *uic,
 		return;
 	}
 
-	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-windows.png", TRUE, NULL);
+	file = gnome_icon_theme_lookup_icon (tasklist->icon_theme,
+					     "panel-window-list",
+					     48, NULL, NULL);
 	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 	g_free(file);
 
 	tasklist->about = gnome_about_new (_("Window List"), VERSION,
 				 "Copyright \xc2\xa9 2001-2002 Red Hat, Inc.",
-				 _("The Window List shows a list of all visible windows and lets you browse them."),
+				 _("The Window List shows a list of all windows and lets you browse them."),
 				 authors,
 				 documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
@@ -954,6 +978,7 @@ setup_dialog (GladeXML     *xml,
 			   "always_group_radio",
 			   "group_windows" /* key */);
 
+	tasklist->minimized_windows_label = WID ("minimized_windows_label");
 	tasklist->move_minimized_radio = WID ("move_minimized_radio");
 	tasklist->change_workspace_radio = WID ("change_workspace_radio");
 
@@ -1027,7 +1052,7 @@ setup_dialog (GladeXML     *xml,
 			  G_CALLBACK (response_cb),
 			  tasklist);
 
-
+	g_object_unref (G_OBJECT (client));
 }
 
 
@@ -1037,6 +1062,8 @@ display_properties_dialog (BonoboUIComponent *uic,
 			   TasklistData      *tasklist,
 			   const gchar       *verbname)
 {
+	gchar *window_icon;
+
 	if (tasklist->properties_dialog == NULL) {
 		GladeXML  *xml;
 
@@ -1051,8 +1078,14 @@ display_properties_dialog (BonoboUIComponent *uic,
 		g_object_unref (G_OBJECT (xml));
 	}
 
-	gnome_window_icon_set_from_file (GTK_WINDOW (tasklist->properties_dialog), 
-					 GNOME_ICONDIR "/gnome-windows.png");
+	window_icon = gnome_icon_theme_lookup_icon (tasklist->icon_theme,
+						    "panel-window-list",
+						    48, NULL, NULL);
+	if (window_icon) {
+		gnome_window_icon_set_from_file (GTK_WINDOW (tasklist->properties_dialog), window_icon);
+		g_free (window_icon);
+	}
+
 	gtk_window_set_resizable (GTK_WINDOW (tasklist->properties_dialog), FALSE);
 	gtk_window_set_screen (GTK_WINDOW (tasklist->properties_dialog),
 			       gtk_widget_get_screen (tasklist->applet));
