@@ -52,7 +52,6 @@
 #include "panel-applet-frame.h"
 #include "quick-desktop-reader.h"
 #include "xstuff.h"
-#include "egg-screen-exec.h"
 #include "panel-stock-icons.h"
 #include "panel-action-button.h"
 #include "panel-recent.h"
@@ -131,7 +130,7 @@ static AppletMenuInfo action_buttons_info [] = {
 	{ N_("Force Quit"),
 	  N_("Actions"),
 	  "Actions",
-	  "Force a misbehaving application to quit",
+	  N_("Force a misbehaving application to quit"),
 	  NULL,
 	  PANEL_STOCK_FORCE_QUIT,
 	  PANEL_ACTION_FORCE_QUIT,
@@ -253,6 +252,7 @@ show_about_dialog (GtkWidget *menuitem)
 	char             *authors [] = {
 		"Alex Larsson (alexl@redhat.com)",
 		"Anders Carlsson (andersca@gnu.org)",
+		"Arvind Samptur (arvind.samptur@wipro.com)",
 		"Darin Adler (darin@bentspoon.com)",
 		"Elliot Lee (sopwith@redhat.com)",
 		"Federico Mena (quartic@gimp.org)",
@@ -269,6 +269,7 @@ show_about_dialog (GtkWidget *menuitem)
 		"Seth Nickell (snickell@stanford.edu)",
 		"Stephen Browne (stephen.browne@sun.com)",
 		"Tom Tromey (tromey@cygnus.com)",
+		"Vincent Untz (vincent@vuntz.net)",
 		N_("And many, many others..."),
 		NULL
 	};
@@ -319,14 +320,17 @@ about_gnome_cb (GtkWidget *menuitem,
 		char      *program_path)
 {
 	GdkScreen *screen = menuitem_to_screen (menuitem);
+	GError    *error = NULL;
 
-	if (egg_screen_execute_async (screen, g_get_home_dir (), 1, &program_path) < 0)
+	if (!gdk_spawn_command_line_on_screen (screen, program_path, &error)) {
 		panel_error_dialog (screen,
 				    "cannot_exec_about_gnome",
 				    _("Cannot execute '%s'"),
-				    _("%s - command not found"),
+				    _("%s: %s"),
 				    _("About GNOME"),
-				    program_path);
+				    program_path, error->message);
+		g_error_free (error);
+	}
 }
 
 static void
@@ -600,7 +604,7 @@ menu_on_screen (GtkMenu  *menu,
 	gtk_widget_get_child_requisition (GTK_WIDGET (menu), &req);
 
 	screen  = gtk_widget_get_screen (GTK_WIDGET (menu));
-	monitor = panel_multiscreen_locate_coords (screen, *x, *y);
+	monitor = gdk_screen_get_monitor_at_point (screen, *x, *y);
 
 	monitor_width  = panel_multiscreen_width (screen, monitor);
 	monitor_height = panel_multiscreen_height (screen, monitor);
@@ -1170,46 +1174,6 @@ add_to_run_dialog (GtkWidget    *widget,
 	}
 }
 
-static void
-show_help_on (GtkWidget    *widget,
-	      ShowItemMenu *sim)
-{
-	GError           *error = NULL;
-	GnomeDesktopItem *item;
-	GdkScreen        *screen;
-
-	screen = menuitem_to_screen (sim->menuitem);
-
-	item = gnome_desktop_item_new_from_uri (sim->item_loc,
-						GNOME_DESKTOP_ITEM_LOAD_NO_TRANSLATIONS,
-						&error);
-	if (item != NULL) {
-		const char *docpath = gnome_desktop_item_get_string
-			(item, "X-GNOME-DocPath");
-		if ( ! panel_show_gnome_kde_help (screen, docpath, &error)) {
-			panel_error_dialog (screen,
-					    "cannot_show_gnome_kde_help",
-					    _("Cannot display help document"),
-					    "%s",
-					    error->message);
-
-			g_clear_error (&error);
-		}
-
-		gnome_desktop_item_unref (item);
-	} else {
-		g_assert (error != NULL);
-
-		panel_error_dialog (screen,
-				    "cannot_load_entry",
-				    _("Cannot load entry"),
-				    "%s",
-				    error->message);
-
-		g_clear_error (&error);
-	}
-}
-
 static void
 add_app_to_panel (GtkWidget    *item,
 		  ShowItemMenu *sim)
@@ -1332,12 +1296,15 @@ add_menudrawer_to_panel (GtkWidget *menuitem,
 
 static void
 add_menu_to_panel (GtkWidget  *widget,
-		   const char *menu_path)
+		   MenuFinfo  *menu_info)
 {
 	PanelWidget   *panel_widget;
 	PanelToplevel *toplevel;
 	PanelData     *pd;
 	int            position;
+	char          *menu_path;
+	gboolean       use_menu_path;
+	char          *tooltip;
 
 	panel_widget = menu_get_panel (widget);
 	toplevel = panel_widget->toplevel;
@@ -1345,7 +1312,19 @@ add_menu_to_panel (GtkWidget  *widget,
 	pd = g_object_get_data (G_OBJECT (toplevel), "PanelData");
 	position = pd ? pd->insertion_pos : -1;
 
-	panel_menu_button_create (toplevel, position, menu_path, menu_path != NULL);
+	if (!menu_info) {
+		menu_path     = NULL;
+		use_menu_path = FALSE;
+		tooltip       = _("Main Menu");
+	} else {
+		menu_path     = menu_info->menudir;
+		use_menu_path = TRUE;
+		tooltip       = menu_info->dir_name ? menu_info->dir_name :
+						      _("Menu");
+	}
+
+	panel_menu_button_create (toplevel, position, menu_path,
+				  use_menu_path, tooltip);
 }
 
 /*most of this function stolen from the real gtk_menu_popup*/
@@ -1476,14 +1455,16 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 				return;
 			}
 
-			menuitem = gtk_image_menu_item_new ();
-			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Add this launcher to panel"), FALSE);
-			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
-			g_signal_connect (menuitem, "activate",
-					  G_CALLBACK (add_app_to_panel),
-					  sim);
-			gtk_widget_set_sensitive (menuitem, objects_writable);
+			if ( ! panel_toplevel_get_locked_down (panel_widget->toplevel)) {
+				menuitem = gtk_image_menu_item_new ();
+				setup_menuitem (menuitem, panel_menu_icon_get_size (),
+						NULL, _("Add this launcher to panel"), FALSE);
+				gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
+				g_signal_connect (menuitem, "activate",
+						  G_CALLBACK (add_app_to_panel),
+						  sim);
+				gtk_widget_set_sensitive (menuitem, objects_writable);
+			}
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
@@ -1501,56 +1482,38 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 						   G_CALLBACK (gtk_menu_shell_deactivate),
 						   G_OBJECT (item->parent));
 
-			menuitem = gtk_image_menu_item_new ();
-			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Put into run dialog"), FALSE);
-			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu),
-					       menuitem);
-			g_signal_connect (menuitem, "activate",
-					  G_CALLBACK (add_to_run_dialog),
-					  sim);
-			g_signal_connect_swapped
-				(G_OBJECT(menuitem),
-				 "activate",
-				 G_CALLBACK(gtk_menu_shell_deactivate),
-				 G_OBJECT(item->parent));
-
-			if (gnome_desktop_item_get_string (ii, "X-GNOME-DocPath") != NULL) {
-				char *title;
-				const char *name;
-
+			if ( ! panel_profile_get_inhibit_command_line ()) {
 				menuitem = gtk_image_menu_item_new ();
-				name = gnome_desktop_item_get_localestring (ii, GNOME_DESKTOP_ITEM_NAME);
-				title = g_strdup_printf (_("Help on %s"),
-							 (name != NULL) ? name : _("Application"));
 				setup_menuitem (menuitem, panel_menu_icon_get_size (),
-						NULL, title, FALSE);
-				g_free (title);
+						NULL, _("Put into run dialog"), FALSE);
 				gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu),
-						 menuitem);
+						       menuitem);
 				g_signal_connect (menuitem, "activate",
-					          G_CALLBACK (show_help_on),
-					          sim);
-				g_signal_connect_swapped (G_OBJECT(menuitem),
-					 		  "activate",
-					 		   G_CALLBACK(gtk_menu_shell_deactivate),
-					 		   G_OBJECT(item->parent));
+						  G_CALLBACK (add_to_run_dialog),
+						  sim);
+				g_signal_connect_swapped
+					(G_OBJECT(menuitem),
+					 "activate",
+					 G_CALLBACK(gtk_menu_shell_deactivate),
+					 G_OBJECT(item->parent));
 			}
 
-			menuitem = gtk_image_menu_item_new ();
-			/*when activated we must pop down the first menu*/
-			g_signal_connect_swapped (G_OBJECT (menuitem),
-						   "activate",
-						   G_CALLBACK (gtk_menu_shell_deactivate),
-						   G_OBJECT (item->parent));
+			if ( ! panel_profile_get_inhibit_command_line ()) {
+				menuitem = gtk_image_menu_item_new ();
+				/*when activated we must pop down the first menu*/
+				g_signal_connect_swapped (G_OBJECT (menuitem),
+							  "activate",
+							  G_CALLBACK (gtk_menu_shell_deactivate),
+							  G_OBJECT (item->parent));
 
-			g_signal_connect (G_OBJECT(menuitem),
-					   "activate",
-					   G_CALLBACK(edit_dentry),
-					   sim);
-			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("_Properties"), FALSE);
-			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
+				g_signal_connect (G_OBJECT(menuitem),
+						  "activate",
+						  G_CALLBACK(edit_dentry),
+						  sim);
+				setup_menuitem (menuitem, panel_menu_icon_get_size (),
+						NULL, _("_Properties"), FALSE);
+				gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
+			}
 
 			gnome_desktop_item_unref (ii);
 		}
@@ -1576,40 +1539,47 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 							   submenu);
 			}
 
+			if ( ! panel_toplevel_get_locked_down (panel_widget->toplevel)) {
+				menuitem = gtk_image_menu_item_new ();
+				setup_menuitem (menuitem, panel_menu_icon_get_size (), NULL,
+						_("Add this as drawer to panel"), FALSE);
+				gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
+				g_signal_connect (G_OBJECT(menuitem), "activate",
+						  G_CALLBACK(add_menudrawer_to_panel),
+						  sim->mf);
+				gtk_widget_set_sensitive (menuitem,
+							  objects_writable &&
+							  toplevels_writable);
 
-			menuitem = gtk_image_menu_item_new ();
-			setup_menuitem (menuitem, panel_menu_icon_get_size (), NULL,
-					_("Add this as drawer to panel"), FALSE);
-			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
-			g_signal_connect (G_OBJECT(menuitem), "activate",
-				   G_CALLBACK(add_menudrawer_to_panel),
-				   sim->mf);
-			gtk_widget_set_sensitive (menuitem, objects_writable && toplevels_writable);
+				menuitem = gtk_image_menu_item_new ();
+				setup_menuitem (menuitem, panel_menu_icon_get_size (),
+						NULL, _("Add this as menu to panel"), FALSE);
+				gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
+				g_signal_connect (G_OBJECT(menuitem), "activate",
+						  G_CALLBACK(add_menu_to_panel),
+						  sim->mf);
+				gtk_widget_set_sensitive (menuitem,
+							  objects_writable &&
+							  toplevels_writable);
+			}
 
-			menuitem = gtk_image_menu_item_new ();
-			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Add this as menu to panel"), FALSE);
-			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
-			g_signal_connect (G_OBJECT(menuitem), "activate",
-					   G_CALLBACK(add_menu_to_panel),
-					   sim->mf->menudir);
-			gtk_widget_set_sensitive (menuitem, objects_writable);
+			if ( ! panel_profile_get_inhibit_command_line ()) {
+				menuitem = gtk_image_menu_item_new ();
+				setup_menuitem (menuitem, panel_menu_icon_get_size (),
+						NULL, _("Add new item to this menu"), FALSE);
+				gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
+				/*when activated we must pop down the first menu*/
+				g_signal_connect_swapped (G_OBJECT (menuitem),
+							  "activate",
+							  G_CALLBACK (gtk_menu_shell_deactivate),
+							  G_OBJECT (item->parent));
 
-			menuitem = gtk_image_menu_item_new ();
-			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Add new item to this menu"), FALSE);
-			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
-			/*when activated we must pop down the first menu*/
-			g_signal_connect_swapped (G_OBJECT (menuitem),
-						 "activate",
-						 G_CALLBACK (gtk_menu_shell_deactivate),
-						 G_OBJECT (item->parent));
-
-			g_signal_connect (menuitem, "activate",
-					  G_CALLBACK (add_new_app_to_menu),
-					  sim);
-			if ( ! panel_is_uri_writable (sim->mf->menudir))
-				gtk_widget_set_sensitive (menuitem, FALSE);
+				g_signal_connect (menuitem, "activate",
+						  G_CALLBACK (add_new_app_to_menu),
+						  sim);
+				if ( ! panel_is_uri_writable (sim->mf->menudir))
+					gtk_widget_set_sensitive (menuitem, FALSE);
+			}
 
 			menuitem = gtk_image_menu_item_new ();
 			/*when activated we must pop down the first menu*/
@@ -1658,7 +1628,7 @@ menuitem_button_press_event (GtkWidget      *menuitem,
 			     ShowItemMenu   *sim)
 {
 	/* no item menu in commie mode */
-	if (commie_mode)
+	if (panel_profile_get_locked_down ())
 		return FALSE;
 	
 	if (event->button == 3) {
@@ -1886,7 +1856,7 @@ setup_full_menuitem (GtkWidget   *menuitem,
 				  G_CALLBACK (destroy_item_menu),
 				  sim);
 
-		if ( ! commie_mode) {
+		if ( ! panel_profile_get_locked_down ()) {
 			gtk_drag_source_set(menuitem,
 					    GDK_BUTTON1_MASK|GDK_BUTTON2_MASK,
 					    menu_item_targets, 1,
@@ -1921,7 +1891,7 @@ setup_applet_drag (GtkWidget *menuitem, const char *iid)
 	};
 	
 	if (iid == NULL ||
-	    commie_mode)
+	    panel_profile_get_locked_down ())
 		return;
 	
 	gtk_drag_source_set (menuitem,
@@ -1947,7 +1917,7 @@ setup_internal_applet_drag (GtkWidget *menuitem, const char *applet_type)
 	};
 	
 	if (applet_type == NULL ||
-	    commie_mode)
+	    panel_profile_get_locked_down ())
 		return;
 	
 	gtk_drag_source_set (menuitem,
@@ -2242,10 +2212,11 @@ create_menuitem (GtkWidget *menu,
 
 	if (fr->type == FILE_REC_DIR) {
 		if (!gnome_folder)
-			gnome_folder = gnome_program_locate_file (NULL, 
-								  GNOME_FILE_DOMAIN_PIXMAP, 
-								  "gnome-folder.png", 
-								  TRUE, NULL);
+			gnome_folder = gnome_icon_theme_lookup_icon (
+						panel_icon_theme,
+                                               "gnome-fs-directory",
+                                               48, NULL, NULL);
+
 		if (!icon)
 			icon = gnome_folder;
 		else
@@ -2680,10 +2651,10 @@ applet_info_sort_func (AppletMenuInfo *a,
 {
 	int c;
 
-	if ((c = strcmp (a->category, b->category)))
+	if ((c = g_utf8_collate (a->category, b->category)))
 		return c;
 
-	return strcmp (a->name, b->name);
+	return g_utf8_collate (a->name, b->name);
 }
 
 static GSList *
@@ -2691,8 +2662,18 @@ append_internal_applets (GSList *list)
 {
 	static gboolean translated = FALSE;
 	int             i;
+	gboolean inhibit_command_line = panel_profile_get_inhibit_command_line ();
+	gboolean inhibit_force_quit = panel_profile_get_inhibit_force_quit ();
 
 	for (i = 0; i < G_N_ELEMENTS (action_buttons_info); i++) {
+		if (inhibit_command_line && 
+		    action_buttons_info [i].action_type == PANEL_ACTION_RUN)
+			continue;
+
+		if (inhibit_force_quit && 
+		    action_buttons_info [i].action_type == PANEL_ACTION_FORCE_QUIT)
+			continue;
+
 		if (!translated) {
 			action_buttons_info [i].name = _(action_buttons_info [i].name);
 			action_buttons_info [i].category = _(action_buttons_info [i].category);
@@ -2716,6 +2697,7 @@ create_applets_menu (GtkWidget             *menu,
 	GSList            *langs_gslist;
 	GSList            *applets = NULL;
 	GSList		  *item = NULL;
+	GSList            *disabled_applets;
 	gboolean           applets_writable;
 	gboolean           objects_writable;
 
@@ -2739,6 +2721,8 @@ create_applets_menu (GtkWidget             *menu,
 		langs_glist = langs_glist->next;
 	}
 
+	disabled_applets = panel_profile_get_disabled_applets ();
+
 	for (i = 0; i < applet_list->_length; i++) {
 		Bonobo_ServerInfo *info;
 		AppletMenuInfo    *applet;
@@ -2750,6 +2734,9 @@ create_applets_menu (GtkWidget             *menu,
 
 		info = &applet_list->_buffer [i];
 
+		if (g_slist_find_custom (disabled_applets, info->iid, (GCompareFunc)strcmp) != NULL)
+			continue;
+
 		name        = bonobo_server_info_prop_lookup (info, "name", langs_gslist);
 		category    = bonobo_server_info_prop_lookup (info, "panel:category", langs_gslist);
 	        description = bonobo_server_info_prop_lookup (info, "description", langs_gslist);
@@ -2767,7 +2754,7 @@ create_applets_menu (GtkWidget             *menu,
 		applet->untranslated_category = untranslated_category;
 		applet->description = description;
 		applet->icon = icon;
-		applet->drag_data = info->iid;;
+		applet->drag_data = info->iid;
 
 		applets = g_slist_append (applets, applet);
 	}
@@ -2816,6 +2803,8 @@ create_applets_menu (GtkWidget             *menu,
 	
 	g_slist_free (langs_gslist);
 	g_slist_free (applets);
+
+	panel_g_slist_deep_free	(disabled_applets);
 	
 	return menu;
 }
@@ -2956,7 +2945,8 @@ setup_remove_this_panel (GtkWidget *menu,
 
 	toplevels_writable = panel_profile_list_is_writable (PANEL_GCONF_TOPLEVELS);
 
-	if (panel_toplevel_is_last_unattached (panel_widget->toplevel))
+	if (panel_toplevel_is_last_unattached (panel_widget->toplevel) ||
+	    panel_toplevel_get_locked_down (panel_widget->toplevel))
 		gtk_widget_set_sensitive(menuitem, FALSE);
 	else
 		/* this can only be sensitive if we can actually write to
@@ -2998,61 +2988,62 @@ make_panel_submenu (PanelWidget *panel_widget,
 	Bonobo_ServerInfoList *applet_list;
 	GtkWidget             *menuitem, *submenu;
 
+	if ( ! panel_toplevel_get_locked_down (panel_widget->toplevel)) {
+		menuitem = gtk_image_menu_item_new ();
+		setup_menuitem (menuitem,
+				GTK_ICON_SIZE_MENU,
+				gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_MENU),
+				_("_Add to Panel"),
+				FALSE);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 
-	menuitem = gtk_image_menu_item_new ();
-	setup_menuitem (menuitem,
-			GTK_ICON_SIZE_MENU,
-			gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_MENU),
-			_("_Add to Panel"),
-			FALSE);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		submenu = menu_new ();
+		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
+					   submenu);
 
-	submenu = menu_new ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
-				   submenu);
+		applet_list = instrument_add_submenu_for_reload (GTK_MENU_ITEM (menuitem), submenu);
 
-	applet_list = instrument_add_submenu_for_reload (GTK_MENU_ITEM (menuitem), submenu);
+		if ( ! panel_profile_list_is_writable (PANEL_GCONF_APPLETS) &&
+		     ! panel_profile_list_is_writable (PANEL_GCONF_OBJECTS)) {
+			/* if we can't write neither applets nor objects, just
+			   completely ignore this and make the whole submenu
+			   insensitive */
+			gtk_widget_set_sensitive (menuitem, FALSE);
+		} else {
+			make_add_submenu (submenu, applet_list);
+		}
 
-	if ( ! panel_profile_list_is_writable (PANEL_GCONF_APPLETS) &&
-	     ! panel_profile_list_is_writable (PANEL_GCONF_OBJECTS)) {
-		/* if we can't write neither applets nor objects, just
-		   completely ignore this and make the whole submenu
-		   insensitive */
-		gtk_widget_set_sensitive (menuitem, FALSE);
-	} else {
-		make_add_submenu (submenu, applet_list);
+		menuitem = gtk_image_menu_item_new ();
+
+		setup_menuitem (menuitem, 
+				GTK_ICON_SIZE_MENU,
+				gtk_image_new_from_stock (GTK_STOCK_DELETE, GTK_ICON_SIZE_MENU),
+				_("_Delete This Panel"),
+				FALSE);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		g_signal_connect (G_OBJECT (menuitem), "activate",
+				  G_CALLBACK (remove_panel),
+				  NULL);
+		g_signal_connect (G_OBJECT (menu), "show",
+				  G_CALLBACK(setup_remove_this_panel),
+				  menuitem);
+
+		menuitem = gtk_image_menu_item_new ();
+		setup_menuitem (menuitem,
+				GTK_ICON_SIZE_MENU,
+				gtk_image_new_from_stock (
+							  GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_MENU),
+				_("_Properties"),
+				FALSE);
+
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		g_signal_connect_swapped (menuitem, "activate",
+					  G_CALLBACK (panel_properties_dialog_present), 
+					  panel_widget->toplevel);
+
+		add_menu_separator (menu);
 	}
 
-	menuitem = gtk_image_menu_item_new ();
-
-	setup_menuitem (menuitem, 
-			GTK_ICON_SIZE_MENU,
-			gtk_image_new_from_stock (GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU),
-			_("_Delete This Panel"),
-			FALSE);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	g_signal_connect (G_OBJECT (menuitem), "activate",
-			    G_CALLBACK (remove_panel),
-			    NULL);
-	g_signal_connect (G_OBJECT (menu), "show",
-			    G_CALLBACK(setup_remove_this_panel),
-			    menuitem);
-
-	menuitem = gtk_image_menu_item_new ();
-	setup_menuitem (menuitem,
-			GTK_ICON_SIZE_MENU,
-			gtk_image_new_from_stock (
-				GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_MENU),
-			_("_Properties"),
-			FALSE);
-
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	g_signal_connect_swapped (menuitem, "activate",
-				  G_CALLBACK (panel_properties_dialog_present), 
-				  panel_widget->toplevel);
-
-	add_menu_separator (menu);
-
 	menuitem = gtk_image_menu_item_new ();
 	setup_menuitem (menuitem, 
 			GTK_ICON_SIZE_MENU,
@@ -3063,8 +3054,6 @@ make_panel_submenu (PanelWidget *panel_widget,
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (create_new_panel), 
 			  NULL);
-	/* this can only be sensitive if we can actually write to the
-	   toplevels list */
 	gtk_widget_set_sensitive (menuitem, 
 				  panel_profile_list_is_writable (PANEL_GCONF_TOPLEVELS));
 
@@ -3087,7 +3076,7 @@ create_panel_context_menu (PanelWidget *panel)
 
 	retval = menu_new ();
 
-	if (!commie_mode)
+	if ( ! panel_profile_get_locked_down ())
 		make_panel_submenu (panel, retval);
 
 	menuitem = gtk_image_menu_item_new ();
@@ -3140,6 +3129,9 @@ ask_about_launcher_cb (GtkWidget *widget)
 	PanelData   *pd;
 	int          insertion_pos;
 
+	if (panel_profile_get_inhibit_command_line ())
+		return;
+
 	panel_widget = menu_get_panel (widget);
 
 	pd = g_object_get_data (G_OBJECT (panel_widget->toplevel), "PanelData");
@@ -3162,14 +3154,16 @@ make_add_submenu (GtkWidget             *menu,
 
 	create_applets_menu (menu, applet_list);
 
-	menuitem = gtk_image_menu_item_new ();
-	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher..."), TRUE);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	g_signal_connect (G_OBJECT(menuitem), "activate",
-			   G_CALLBACK(ask_about_launcher_cb),NULL);
-	setup_internal_applet_drag(menuitem, "LAUNCHER:ASK");
-	gtk_widget_set_sensitive (menuitem, objects_writable);
+	if ( ! panel_profile_get_inhibit_command_line ()) {
+		menuitem = gtk_image_menu_item_new ();
+		setup_stock_menu_item (
+				       menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher..."), TRUE);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		g_signal_connect (G_OBJECT(menuitem), "activate",
+				  G_CALLBACK(ask_about_launcher_cb),NULL);
+		setup_internal_applet_drag(menuitem, "LAUNCHER:ASK");
+		gtk_widget_set_sensitive (menuitem, objects_writable);
+	}
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
@@ -3214,8 +3208,11 @@ make_add_submenu (GtkWidget             *menu,
 static GtkWidget *
 create_desktop_menu (GtkWidget *menu, gboolean fake_submenus)
 {
-	GtkWidget *menuitem;
 	/* Panel entry */
+	GtkWidget  *menuitem;
+	char       *logout_string;
+	char       *logout_tooltip;
+	const char *user_name;
 
 	if (menu == NULL) {
 		menu = menu_new ();
@@ -3232,21 +3229,32 @@ create_desktop_menu (GtkWidget *menu, gboolean fake_submenus)
 		setup_internal_applet_drag(menuitem, "ACTION:lock:NEW");
 		gtk_tooltips_set_tip (panel_tooltips, menuitem,
 				      _("Lock the screen so that you can "
-					"temporarily leave your computer"), NULL);
+					"temporarily leave your computer"),
+				      NULL);
 	}
 
-	menuitem = gtk_image_menu_item_new ();
-	setup_stock_menu_item (
-		menuitem, panel_menu_icon_get_size (), PANEL_STOCK_LOGOUT, _("Log Out"), TRUE);
+ 	menuitem = gtk_image_menu_item_new ();
+
+	logout_string = g_strdup_printf (_("Log Out %s"), g_get_user_name ());
+ 	setup_stock_menu_item (menuitem, panel_menu_icon_get_size (),
+			       PANEL_STOCK_LOGOUT, logout_string, TRUE);
+	g_free (logout_string);
+
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (panel_action_logout), 0);
 	setup_internal_applet_drag(menuitem, "ACTION:logout:NEW");
-	gtk_tooltips_set_tip (panel_tooltips, menuitem,
-			      _("Log out of this session to log in as "
-				"a different user or to shut down your "
-				"computer"),
-			      NULL);
+
+	user_name = g_get_real_name ();
+	if (!user_name || !user_name [0])
+		user_name = g_get_user_name ();
+	
+	logout_tooltip = g_strdup_printf (_("Log out %s of this session to "
+					    "log in as a different user or to "
+					    "to shut down your computer"),
+					  user_name);
+	gtk_tooltips_set_tip (panel_tooltips, menuitem, logout_tooltip, NULL);
+	g_free (logout_tooltip);
 
 	return menu;
 }
@@ -3362,7 +3370,7 @@ create_root_menu (GtkWidget   *root_menu,
 					  FALSE /*launcher_add */);
 	}
 
-	if ( ! no_run_box && extra_items) {
+	if ( ! panel_profile_get_inhibit_command_line () && extra_items) {
 		add_menu_separator (root_menu);
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
