@@ -39,6 +39,8 @@
 #include "panel-globals.h"
 #include "panel-profile.h"
 
+#define PANEL_MENU_BAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_MENU_BAR, PanelMenuBarPrivate))
+
 #define MENU_FLAGS (MAIN_MENU_SYSTEM | MAIN_MENU_DISTRIBUTION_SUB)
 
 enum {
@@ -101,7 +103,10 @@ panel_menu_bar_append_action_item (PanelMenuBar *menubar,
 static void
 panel_menu_bar_append_actions_menu (PanelMenuBar *menubar)
 {
-	GtkWidget *item;
+	GtkWidget  *item;
+	char       *logout_string;
+	char       *logout_tooltip;
+	const char *user_name;
 
 	menubar->priv->actions_menu = panel_create_menu ();
 
@@ -167,14 +172,22 @@ panel_menu_bar_append_actions_menu (PanelMenuBar *menubar)
 			"ACTION:lock:NEW",
 			G_CALLBACK (panel_action_lock_screen));
 
+	user_name = g_get_real_name ();
+	if (!user_name || !user_name [0])
+		user_name = g_get_user_name ();
+	logout_string  = g_strdup_printf (_("Log Out %s"), g_get_user_name ());
+	logout_tooltip = g_strdup_printf (_("Quit from %s's desktop"),
+					  user_name);
 	panel_menu_bar_append_action_item (
 			menubar,
 			menubar->priv->actions_menu,
-			_("Log Out"),
+			logout_string,
 			PANEL_STOCK_LOGOUT,
-			_("Quit from the GNOME desktop"),
+			logout_tooltip,
 			"ACTION:logout:NEW",
 			G_CALLBACK (panel_action_logout));
+	g_free (logout_string);
+	g_free (logout_tooltip);
 
 	item = gtk_menu_item_new_with_label (_("Actions"));
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), menubar->priv->actions_menu);
@@ -188,7 +201,7 @@ panel_menu_bar_instance_init (PanelMenuBar      *menubar,
 	GtkWidget *item;
 	GtkWidget *image;
 
-	menubar->priv = g_new0 (PanelMenuBarPrivate, 1);
+	menubar->priv = PANEL_MENU_BAR_GET_PRIVATE (menubar);
 
 	menubar->priv->info = NULL;
 
@@ -222,19 +235,6 @@ panel_menu_bar_instance_init (PanelMenuBar      *menubar,
 	panel_menu_bar_append_actions_menu (menubar);
 }
 
-static void
-panel_menu_bar_finalize (GObject *object)
-{
-	PanelMenuBar *menubar = PANEL_MENU_BAR (object);
-
-	menubar->priv->info = NULL;
-
-	g_free (menubar->priv);
-	menubar->priv = NULL;
-
-	parent_class->finalize (object);
-}
-
 static void
 panel_menu_bar_parent_set (GtkWidget *widget,
 			   GtkWidget *previous_parent)
@@ -252,18 +252,16 @@ panel_menu_bar_parent_set (GtkWidget *widget,
 }
 
 static void
-panel_menu_bar_class_init (PanelMenuBarClass *klass,
-			   gpointer           dummy)
+panel_menu_bar_class_init (PanelMenuBarClass *klass)
 {
-	GObjectClass   *gobject_class = (GObjectClass   *) klass;
 	GtkWidgetClass *widget_class  = (GtkWidgetClass *) klass;
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	gobject_class->finalize = panel_menu_bar_finalize;
-
 	widget_class->parent_set = panel_menu_bar_parent_set;
 
+	g_type_class_add_private (klass, sizeof (PanelMenuBarPrivate));
+
 	gtk_rc_parse_string (
 		"style \"panel-menubar-style\"\n"
 		"{\n"
@@ -363,7 +361,7 @@ panel_menu_bar_invoke_menu (PanelMenuBar *menubar,
 
 	screen = gtk_widget_get_screen (GTK_WIDGET (menubar));
 
-	panel_show_help (screen, "wgospanel.xml", NULL);
+	panel_show_help (screen, "wgospanel.xml", "gospanel-37");
 }
 
 void
