@@ -31,6 +31,13 @@
 
 G_BEGIN_DECLS
 
+/* We need PanelWidget type but don't want to include
+   the panel-widget.h */
+#ifndef TYPEDEF_PANEL_WIDGET
+typedef struct _PanelWidget		PanelWidget;
+#define TYPEDEF_PANEL_WIDGET
+#endif /* TYPEDEF_PANEL_WIDGET */
+
 #define PANEL_TYPE_TOPLEVEL         (panel_toplevel_get_type ())
 #define PANEL_TOPLEVEL(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), PANEL_TYPE_TOPLEVEL, PanelToplevel))
 #define PANEL_TOPLEVEL_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), PANEL_TYPE_TOPLEVEL, PanelToplevelClass))
@@ -68,7 +75,7 @@ struct _PanelToplevelClass {
 GType                panel_toplevel_get_type            (void) G_GNUC_CONST;
 GtkWidget           *panel_toplevel_new                 (void);
 
-gpointer             panel_toplevel_get_panel_widget    (PanelToplevel       *toplevel);
+PanelWidget         *panel_toplevel_get_panel_widget    (PanelToplevel       *toplevel);
 
 void                 panel_toplevel_set_name            (PanelToplevel       *toplevel,	
 							 const char          *name);
@@ -115,6 +122,8 @@ gboolean             panel_toplevel_get_is_attached     (PanelToplevel       *to
 PanelToplevel       *panel_toplevel_get_attach_toplevel (PanelToplevel       *toplevel);
 GtkWidget           *panel_toplevel_get_attach_widget   (PanelToplevel       *toplevel);
 
+gboolean             panel_toplevel_get_is_floating	(PanelToplevel       *toplevel);
+
 gboolean             panel_toplevel_get_is_hidden       (PanelToplevel       *toplevel);
 PanelState           panel_toplevel_get_state           (PanelToplevel       *toplevel);
 
@@ -152,6 +161,9 @@ void                 panel_toplevel_set_enable_arrows   (PanelToplevel       *to
 gboolean             panel_toplevel_get_enable_arrows   (PanelToplevel       *toplevel);
 void                 panel_toplevel_update_edges        (PanelToplevel       *toplevel);
 
+gboolean             panel_toplevel_get_locked_down     (PanelToplevel       *toplevel);
+void                 panel_toplevel_set_locked_down     (PanelToplevel       *toplevel,
+							 gboolean             locked);
 
 gboolean             panel_toplevel_is_last_unattached  (PanelToplevel       *toplevel);
 GSList              *panel_toplevel_list_toplevels      (void);
